function [chebladd]=chebladd(n,rs,rl,wc,rippledb);
% chebladd
% chebladd(n,rs,rl,wc,rippledb) calculates ladder
% filter elements for an 'n'th order Chebyshev filter
% with load resistance 'rl', source resistance 'rs', cut-off
% angular frequency 'wc' and the ripple in db 'rippledb'.
% The result is given as a column vector with
% first element value being the series inductor
% at the source side. If the specified ripple is not
% implementable an empty matrix is returned.
% Note: the cut-off frequency refers to
% the ripple level (not 3dB) cut-off frequency.
% Ref:
% Wai-Kai Chen, "Passive and Active Filters -
% theory and implementations", Wiley, 1986.

% 1997-03-07 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1997. All rights reserved
%
% 1998-01-26 - changed explaining text above
% and added spec.ripple against max ripple check

% Calculate ripple factor epsilon
epsil=sqrt(10^(rippledb/10)-1);


% Calculate max allowable ripple for even order
% filters based on Rs/RL relation

maxrippledb=10*log10((rs+rl)^2/(4*rs*rl));


% If filter order is even and wanted ripple is larger than
% maximum ripple allowed then return with empty matrix.

if floor(n/2)==n/2,
	if maxrippledb<rippledb,
   		chebladd=[];
         return;
      end
end

% Calculate DC gain
% if even order
if floor(n/2)==n/2
	if rl==rs
		kn=1;
	elseif rl>rs
		kn=(1-(1-2/((rl/rs)+1))^2)*(1+epsil^2);
	else
		kn=(1-(1-2/((rs/rl)+1))^2)*(1+epsil^2);
	end

else
	if rl>rs
		kn=(1-(1-2/((rl/rs)+1))^2);
	else
		kn=(1-(1-2/((rs/rl)+1))^2);
	end
end


a=(1/n)*asinh(1/epsil);
aroof=(1/n)*asinh(sqrt(1-kn)/epsil);

element(1,1)=2*rs*sin(pi/(2*n))/(wc*(sinh(a)-sinh(aroof)));

for m=1:1:floor((n-1)/2),
	gamma4mm3=(4*m-3)*pi/(2*n);
	gamma4mm1=(4*m-1)*pi/(2*n);
	gamma4mm2=(4*m-2)*pi/(2*n);
	element(2*m,1)=4*sin(gamma4mm3)*sin(gamma4mm1)/(wc^2*element(2*m-1,1)*...
		(sinh(a)^2+sinh(aroof)^2+sin(gamma4mm2)^2-2*sinh(a)*sinh(aroof)*cos(gamma4mm2)));
	gamma4mm1=(4*m-1)*pi/(2*n);
	gamma4m=4*m*pi/(2*n);
	gamma4mp1=(4*m+1)*pi/(2*n);
	element(2*m+1,1)=4*sin(gamma4mm1)*sin(gamma4mp1)/(wc^2*element(2*m,1)*...
		(sinh(a)^2+sinh(aroof)^2+sin(gamma4m)^2-2*sinh(a)*sinh(aroof)*cos(gamma4m)));
end

% if even - add final element
if floor(n/2)==n/2
	element(n,1)=2*sin(pi/(2*n))/(rl*(sinh(a)+sinh(aroof))*wc);
end

chebladd=element;