function [drawbarc]=drawbarc(b,gstart,gstop,linewidth,linestyle,linecolor,markersize);
% drawbarc
% drawbarc(g,bstart,bstop,linewidth,linestyle,linecolor,markersize)
% Draws one or several constant-susceptance arcs in the current (Smith) graph
%
% Parameters (column vector in case of multiple arcs):
% b - normalized susceptance
% gstart - start conductance
% gstop - stop conductance
%
% Optional:
% linewidth - in 1/72 inch (points)
% linestyle - MATLAB parameter Ex. '-', '-.' etc
% linecolor - [R,G,B]
% markersize - in 1/72 inch (points)
% 
% drawbarc returns a handle to the objects drawn. In case of
% multiple arcs a vertical vector is returned containing the
% handles.


% 1996-12-18 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.


% Global variables for parameters that are not specified
global daelibinitialized
global daecircleresolution
global daelinewidth
global daelinestyle
global daelinecolor
global daemarkersize

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

% Set undefined parameters 
if nargin==3,
	linecolor=daelinecolor;
	linestyle=daelinestyle;
	linewidth=daelinewidth;
	markersize=daemarkersize;
else
	if nargin<7 markersize=daemarkersize; end
	if nargin<6 linecolor=daelinecolor; end
	if nargin<5 linestyle=daelinestyle; end
end

% Number of arcs
c=length(b);

% storage for handles
h=zeros(c,1);

if c==1,
	center=-1-i/b;
	radius=abs(1/b);

	
	if b>0,
		if gstart>gstop,
			tmp=gstart;
			gstart=gstop;
			gstop=tmp;
		end

	else
		if gstart<gstop,
			tmp=gstart;
			gstart=gstop;
			gstop=tmp;
		end
	end
	
	startangle=180*angle(nz2g(1/(gstart+i*b))-center)/pi;
	stopangle=180*angle(nz2g(1/(gstop+i*b))-center)/pi;
		
	h(1,1)=drawarc([center,radius,startangle,stopangle],linewidth,linestyle,linecolor,markersize);
else
	cc=size(linewidth);
	if cc(1,1)==1, linewidth=ones(c,1)*linewidth; end

	cc=size(linestyle);
	if cc(1,1)==1, linestyle=setstr(ones(c,1)*linestyle); end
	
	cc=size(linecolor);
	if cc(1,1)==1, linecolor=ones(c,1)*linecolor; end

	cc=size(markersize);
	if cc(1,1)==1, markersize=ones(c,1)*markersize; end
	
	for k=1:c,
		center=-1-i/b(k,1);
		radius=abs(1/b(k,1));
		
		if b(k,1)>0,
			if gstart(k,1)>gstop(k,1),
				tmp=gstart(k,1);
				gstart(k,1)=gstop(k,1);
				gstop(k,1)=tmp;
			end

		else
			if gstart(k,1)<gstop(k,1),
				tmp=gstart(k,1);
				gstart(k,1)=gstop(k,1);
				gstop(k,1)=tmp;
			end
		end
		
		startangle=180*angle(nz2g(1/(gstart(k,1)+i*b(k,1)))-center)/pi;
		stopangle=180*angle(nz2g(1/(gstop(k,1)+i*b(k,1)))-center)/pi;
		h(k,1)=drawarc([center,radius,startangle,stopangle],linewidth(k,1),linestyle(k,:),linecolor(k,:),markersize(k,:));
	end
end

drawbarc=h;

