function [drawxarc]=drawxarc(x,rstart,rstop,linewidth,linestyle,linecolor,markersize);
% drawxarc
% drawxarc(r,xstart,xstop,linewidth,linestyle,linecolor,markersize)
% Draws one or several constant-reactance arcs in the current (Smith) graph
%
% Parameters (column vector in case of multiple arcs):
% x - normalized reactance
% rstart - start resistance (drawxarc always draws counterclockwise)
% rstop - stop resistance
%
% Optional (column vectors not allowed):
% linewidth - in 1/72 inch (points)
% linestyle - MATLAB parameter Ex. '-', '-.' etc
% linecolor - [R,G,B]
% markersize - in 1/72 inch (points)
% 
% drawrarc returns a handle to the objects drawn. In case of
% multiple arcs a vertical vector is returned containing the
% handles.


% 1996-12-18 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.


% Global variables for parameters that are not specified
global daelibinitialized
global daecircleresolution
global daelinewidth
global daelinestyle
global daelinecolor
global daemarkersize

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

% Set undefined parameters 
if nargin==3,
	linecolor=daelinecolor;
	linestyle=daelinestyle;
	linewidth=daelinewidth;
	markersize=daemarkersize;
else
	if nargin<7 markersize=daemarkersize; end
	if nargin<6 linecolor=daelinecolor; end
	if nargin<5 linestyle=daelinestyle; end
end

% Number of arcs
c=length(x);

% storage for handles
h=zeros(c,1);

if c==1
	center=1+i/x;
	radius=abs(1/x);
	
		
	if x>0,
		if rstart>rstop,
			tmp=rstart;
			rstart=rstop;
			rstop=tmp;
		end

	else
		if rstart<rstop,
			tmp=rstart;
			rstart=rstop;
			rstop=tmp;
		end
	end
	
	startangle=180*angle(nz2g(rstart+i*x)-center)/pi;
	stopangle=180*angle(nz2g(rstop+i*x)-center)/pi;
   
   linestyle=setstr(linestyle);
   
	h(1,1)=drawarc([center,radius,startangle,stopangle],linewidth,linestyle,linecolor,markersize);
else

	cc=size(linewidth);
	if cc(1,1)==1, linewidth=ones(c,1)*linewidth; end

	cc=size(linestyle);
	if cc(1,1)==1, linestyle=setstr(ones(c,1)*linestyle); end
	
	cc=size(linecolor);
	if cc(1,1)==1, linecolor=ones(c,1)*linecolor; end

	cc=size(markersize);
	if cc(1,1)==1, markersize=ones(c,1)*markersize; end
	
	for k=1:c,
		center=1+i/x(k,1);
		radius=abs(1/x(k,1));
		
		if x(k,1)>0,
			if rstart(k,1)>rstop(k,1),
				tmp=rstart(k,1);
				rstart(k,1)=rstop(k,1);
				rstop(k,1)=tmp;
			end

		else
			if rstart(k,1)<rstop(k,1),
				tmp=rstart(k,1);
				rstart(k,1)=rstop(k,1);
				rstop(k,1)=tmp;
			end
		end
		startangle=180*angle(nz2g(rstart(k,1)+i*x(k,1))-center)/pi;
		stopangle=180*angle(nz2g(rstop(k,1)+i*x(k,1))-center)/pi;
		h(k,1)=drawarc([center,radius,startangle,stopangle],linewidth(k,1),linestyle(k,:),linecolor(k,:),markersize(k,:));
	end
end

drawxarc=h;

